summaryrefslogtreecommitdiffstats
path: root/ztest.cc
diff options
context:
space:
mode:
authorDaniel Baumann <daniel.baumann@progress-linux.org>2024-01-23 05:54:13 +0000
committerDaniel Baumann <daniel.baumann@progress-linux.org>2024-01-23 05:54:13 +0000
commite50d8921980602c5569b31dd9d12a24b43a196e8 (patch)
treed7240fd2cd209b129f72dac13832b6cfce13dc76 /ztest.cc
parentReleasing debian version 1.12-3. (diff)
downloadzutils-e50d8921980602c5569b31dd9d12a24b43a196e8.tar.xz
zutils-e50d8921980602c5569b31dd9d12a24b43a196e8.zip
Merging upstream version 1.13~rc1.
Signed-off-by: Daniel Baumann <daniel.baumann@progress-linux.org>
Diffstat (limited to 'ztest.cc')
-rw-r--r--ztest.cc26
1 files changed, 13 insertions, 13 deletions
diff --git a/ztest.cc b/ztest.cc
index 204fee8..9b5dadd 100644
--- a/ztest.cc
+++ b/ztest.cc
@@ -1,4 +1,4 @@
/* Ztest - verify the integrity of compressed files
Copyright (C) 2010-2023 Antonio Diaz Diaz.
This program is free software: you can redistribute it and/or modify
@@ -50,28 +50,28 @@ namespace {
void show_help()
{
- std::printf( "ztest verifies the integrity of the compressed files specified. It\n"
+ std::printf( "ztest checks the integrity of the compressed files specified. It\n"
"also warns if an uncompressed file has a compressed file name extension, or\n"
"if a compressed file has a wrong compressed extension. Uncompressed files\n"
"are otherwise ignored. If a file is specified as '-', the integrity of\n"
- "compressed data read from standard input is verified. Data read from\n"
+ "compressed data read from standard input is checked. Data read from\n"
"standard input must be all in the same compressed format. If a file fails to\n"
"decompress, does not exist, can't be opened, or is a terminal, ztest\n"
- "continues verifying the rest of the files. A final diagnostic is shown at\n"
+ "continues testing the rest of the files. A final diagnostic is shown at\n"
"verbosity level 1 or higher if any file fails the test when testing multiple\n"
"files.\n"
"\nIf no files are specified, recursive searches examine the current\n"
"working directory, and nonrecursive searches read standard input.\n"
"\nThe formats supported are bzip2, gzip, lzip, xz, and zstd.\n"
- "\nNote that error detection in the xz format is broken. First, some xz\n"
- "files lack integrity information. Second, not all xz decompressors can\n"
- "verify the integrity of all xz files. Third, section 2.1.1.2 'Stream\n"
- "Flags' of the xz format specification allows xz decompressors to produce\n"
- "garbage output without issuing any warning. Therefore, xz files can't\n"
- "always be verified as reliably as files in the other formats can.\n"
+ "\nNote that error detection in the xz format is broken. First, some xz files\n"
+ "lack integrity information. Second, not all xz decompressors can check the\n"
+ "integrity of all xz files. Third, section 2.1.1.2 'Stream Flags' of the\n"
+ "xz format specification allows xz decompressors to produce garbage output\n"
+ "without issuing any warning. Therefore, xz files can't always be checked as\n"
+ "reliably as files in the other formats can.\n"
"\nUsage: ztest [options] [files]\n"
- "\nExit status is 0 if all compressed files verify OK, 1 if environmental\n"
- "problems (file not found, invalid command line options, I/O errors, etc),\n"
+ "\nExit status is 0 if all compressed files check OK, 1 if environmental\n"
+ "problems (file not found, invalid command-line options, I/O errors, etc),\n"
"2 if any compressed file is corrupt or invalid, or if any file has an\n"
"incorrect file name extension.\n"
"\nOptions:\n"
@@ -303,7 +303,7 @@ int main( const int argc, const char * const argv[] )
case lz_opt: parse_compressor( arg, pn, fmt_lz, 1 ); break;
case xz_opt: parse_compressor( arg, pn, fmt_xz, 1 ); break;
case zst_opt: parse_compressor( arg, pn, fmt_zst, 1 ); break;
- default : internal_error( "uncaught option." );
+ default: internal_error( "uncaught option." );
}
} // end process options
@@ -1,4 +1,4 @@
-/* Ztest - verify the integrity of compressed files
+/* Ztest - check the integrity of compressed files
Copyright (C) 2010-2023 Antonio Diaz Diaz.
This program is free software: you can redistribute it and/or modify